[![Build Status](https://travis-ci.org/devopsicon/sales-microservice.svg?branch=develop)](https://travis-ci.org/devopsicon/sales-microservice)
[![Maintainability](https://api.codeclimate.com/v1/badges/630cd6efec7556bb413f/maintainability)](https://codeclimate.com/github/devopsicon/sales-microservice/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/630cd6efec7556bb413f/test_coverage)](https://codeclimate.com/github/devopsicon/sales-microservice/test_coverage)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Docker Repository on Quay](https://quay.io/repository/devopsicon/salesmicroservice/status "Docker Repository on Quay")](https://quay.io/repository/devopsicon/salesmicroservice)
[![Gitter chat](https://badges.gitter.im/gitterHQ/gitter.png)](https://gitter.im/devopsicon/java)


# Sales Microservice
Bodach Protection Corp's sales microservice responsible for providing sales capabilities to our fictional
application.

## Development notes

### MySQL and Docker
Sales microservices assumes a mySQL database to exist in localhost with following
variables to be injected as part of environmental variables.
>jdbc.url=jdbc:mysql://localhost:3306/sales
jdbc.username=root
jdbc.password=my-secret-pw
jdbc.driverClassName=com.mysql.jdbc.Driver

A great way to accomplish this is to run the following command to deploy mySQL via docker:
>docker run --name some-mysql -p 3306:3306 -e MYSQL_ROOT_PASSWORD=my-secret-pw -d mysql:5.7

Subsequently a new database called "Sales" must be created in the following manner via SQL IDE on the same db:
>create database sales;

### Flyway and Hibernate Schema Validation
Flyway versioning is automatically in-built during startup of the application.
Flyway will automatically create sales table using /src/main/resources/db/migration scripts.

Hibernate will validate the schema using java entity classes to ensure database structure matches entity definitions.

## API documentation
* Swagger 2 standard API documentation is autogenerated at root/swagger-ui.html such as localhost:8080/swagger-ui.html if server is launched on port 8080 locally.

## Testing locations
* [Unit and Integration](https://github.com/devopsicon/sales-microservice/tree/develop/src/test/java/com/devopsicon/microservices/sales)
* [Functional](https://github.com/devopsicon/sales-microservice/tree/develop/src/cucumberTest)
* [Performance](https://github.com/devopsicon/sales-microservice/tree/develop/src/perfTest)

## DevOps Automation Notes
* TravisCI configuration is via .travis.yml file
* Docker configuration is via Dockerfile

## Contribution Notes
1. This project uses Gradle and Lombok
2. All tests must be done as pre-merged checks
3. master and development branches is protected and only way to contribute is via Pull-Request
4. Unit and Integration testing coverage is monited via CodeClimate

## Deployment Notes
- Github master branch merger is handled via Travis Encrypt, for details please take a look at push commit code to master branch


## TODO
1. Adding Release and Tagging from Master
